

.. include:: ../README.rst


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   manual/overview
   manual/python_interface
   manual/adding_problems
   manual/adding_rules
   manual/default_files/index
   source/newclid

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
